Learn R Programming

qtlnet (version 1.2.4)

dist.qtlnet: QTL network diagnostic routines

Description

Various QTLnet diagnostic routines.

Usage

dist.qtlnet(qtlnet.object, min.prob = 0.9, method = "manhattan", cex = 5)
edgematch.qtlnet(qtlnet.object, min.prob = 0.9, method = "manhattan", cex = 5)
mds.qtlnet(qtlnet.object, min.prob = 0.9, method = "manhattan", cex = 5)
plotbic.qtlnet(x, ..., smooth = TRUE)

Arguments

qtlnet.object,x
Object of class qtlnet.
min.prob
Minimum probability to include edge in network.
method
Distance method to be used between columns of connection matrix. Used by dist. (Only used for mds.qtlnet.)
cex
Character expansion. (Only used for mds.qtlnet, scaled by range of BIC values.)
smooth
Use lowess smoother if TRUE.
...
Additional unused arguments.

Value

  • List containing, for each phenotype in the network, a character vector of the QTL names as chr@pos, or pseudomarker name if chr.pos is FALSE.

References

Chaibub Neto E, Keller MP, Attie AD, Yandell BS (2010) Causal Graphical Models in Systems Genetics: a unified framework for joint inference of causal network and genetic architecture for correlated phenotypes. Ann Appl Statist 4: 320-339. http://www.stat.wisc.edu/~yandell/doc/2010/92.AnnApplStat.pdf

See Also

mcmc.qtlnet

Examples

Run this code
loci.qtlnet(Pscdbp.qtlnet)

Run the code above in your browser using DataLab