Learn R Programming

qtlnet (version 1.3.3)

generate.qtl: Generate QTLs ane phenotypes from cross object

Description

Generate QTLs ane phenotype data for individual examples from cross. These are utility routines to illustrate the examples. They are not meant for users per se.

Usage

generate.qtl.markers(cross, n.phe, nqtl = 3)
generate.qtl.pheno(name, cross, bp, bq, stdev, allqtl,
    burnin = 2000, geno)

Arguments

cross
object of class cross; see read.cross
name
character string for example name
bp
vector or matrix of coefficients for dependencies between phenotypes; see cyclic and acyclic examples
bq
vector or matrix of coefficients for QTL effects on phenotypes; see cyclic and acyclic examples
stdev
vector of standard deviations per phenotype
allqtl
list of objects of class qtl produced by generate.qtl.sample
burnin
number of burnin cycles for MCMC; default is 2000
geno
genotypes at markers, typically extracted with pull.geno
n.phe
number of phenotypes
nqtl
number of QTL

See Also

acyclic, cyclica, cyclicb, cyclicc

Examples

Run this code
example(acyclic)
example(cyclica)
example(cyclicb)
example(cyclicc)

Run the code above in your browser using DataLab