Learn R Programming

qtlnet (version 1.2.4)

summary.qtlnet: summary of model average network and posterior table

Description

Print and summary methods for qtlnet objects.

Usage

## S3 method for class 'qtlnet':
print(x, cutoff = 0.01, digits = 3, \dots)
## S3 method for class 'qtlnet':
summary(object, parent.patterns = FALSE, \dots)
## S3 method for class 'summary.qtlnet':
print(x, \dots)
check.qtlnet(object, min.prob = 0.9, correct = TRUE, verbose = FALSE, ...)

Arguments

x,object
Object of class qtlnet.
cutoff
Frequency cutoff for model patterns to be displayed. Always shows at least the most common pattern.
digits
Number of digits to display for posterior probabilities on directed edges.
parent.patterns
Include summary of parent patterns if TRUE.
min.prob
Set the minimum posterior probability for inclusion of an edge.
correct
Correct min.prob if TRUE.
verbose
Print forbidden edges in model-averaged solution if TRUE.
...
Other hidden arguments. These include min.prob, which can also be passed to other igraph.qtlnet and plot.qtlnet routines.

References

Chaibub Neto E, Keller MP, Attie AD, Yandell BS (2010) Causal Graphical Models in Systems Genetics: a unified framework for joint inference of causal network and genetic architecture for correlated phenotypes. Ann Appl Statist 4: 320-339. http://www.stat.wisc.edu/~yandell/doc/2010/92.AnnApplStat.pdf

See Also

mcmc.qtlnet

Examples

Run this code
data(Pscdbp.qtlnet)
print(Pscdbp.qtlnet)
summary(Pscdbp.qtlnet)

Run the code above in your browser using DataLab