Learn R Programming

qtlnet (version 1.2.4)

loci.qtlnet: QTL architecture per node as list

Description

Determines QTL that affect each phenotype conditional on the model-averaged network and on covariates.

Usage

loci.qtlnet(qtlnet.object, chr.pos = TRUE, merge.qtl = 10, ...)
est.qtlnet(qtlnet.object, ..., verbose = TRUE)

Arguments

qtlnet.object
Object of class qtlnet.
chr.pos
Include chromsome and position if TRUE.
merge.qtl
Merge QTL within merge.qtl cM of the mean QTL per chromosome across all nodes. No merge if 0 or less. This can reduce the number of QTL nodes to one per chr.
...
Additional unused arguments.
verbose
verbose output if TRUE.

Value

  • List containing, for each phenotype in the network, a character vector of the QTL names as chr@pos, or pseudomarker name if chr.pos is FALSE.

References

Chaibub Neto E, Keller MP, Attie AD, Yandell BS (2010) Causal Graphical Models in Systems Genetics: a unified framework for joint inference of causal network and genetic architecture for correlated phenotypes. Ann Appl Statist 4: 320-339. http://www.stat.wisc.edu/~yandell/doc/2010/92.AnnApplStat.pdf

See Also

mcmc.qtlnet

Examples

Run this code
loci.qtlnet(Pscdbp.qtlnet)

Run the code above in your browser using DataLab